#!/usr/bin/env node

const { execSync } = require('child_process');
const path = require('path');
const fs = require('fs');

const runCommand = (command) => {
  try {
    execSync(command, { stdio: 'inherit' });
  } catch (e) {
    console.error(`Failed to execute ${command}`, e);
    return false;
  }
  return true;
};

const removeGitDirectory = (directoryPath) => {
  const gitPath = path.join(directoryPath, '.git');

  try {
    if (fs.existsSync(gitPath)) {
      fs.readdirSync(gitPath).forEach((file) => {
        const filePath = path.join(gitPath, file);
        fs.rmSync(filePath, { recursive: true, force: true });
      });

      fs.rmSync(gitPath, { recursive: true, force: true });
      console.log(`Removed .git directory from ${directoryPath}`);
    }
  } catch (error) {
    console.error(`Failed to remove .git directory from ${directoryPath}`, error);
  }
};

const RepoName = process.argv[2];
const GitCheckoutCommand = `git clone --depth 1 https://github.com/Renstrio24p/Standalone-Typescript-Vite.git ${RepoName}`;
const installDepsCommand = `cd ${RepoName} && npm install`;

console.log(`Cloning the Repository with ${RepoName}`);
const CheckOut = runCommand(GitCheckoutCommand);
if (!CheckOut) process.exit(-1);

console.log(`Removing .git directory from ${RepoName}`);
removeGitDirectory(RepoName);

console.log(`Installing TypeScript Dependencies for ${RepoName}`);
const InstalledDeps = runCommand(installDepsCommand);
if (!InstalledDeps) process.exit(-1);

console.log(`Standalone TypeScript is installed.\n\n Go to ${RepoName} and run npm start`);
